validate_prefix

Function validate_prefix 

pub(super) fn validate_prefix(prefix: &str) -> Result<()>
Available on crate feature turso only.
Validates that prefix is safe to splice into table identifiers.

Errors

Returns io::ErrorKind::InvalidInput if the prefix starts with a digit or contains anything other than ASCII alphanumerics and underscores.